### R code from vignette source 'margLikArrogance.Rnw'

###################################################
### code chunk number 1: SourceR
###################################################
library(favir)
InitPaper()


###################################################
### code chunk number 2: LatexPrelude
###################################################
IncludePrelude("Marginal Likelihood Estimation via Arrogance Sampling",
               "Benedict Escoto", header.lines="\\usepackage{amssymb,amsmath}
\\newcommand{\\bx}{\\boldsymbol x}
\\newcommand{\\btheta}{\\boldsymbol \\theta}
\\newcommand{\\myvar}{\\mbox{Var}}
\\newcommand{\\myexp}{\\mbox{E}}
\\newcommand{\\norm}[1]{\\lVert#1\\rVert}
",
               include.logo=FALSE)


###################################################
### code chunk number 3: Histograms
###################################################
set.seed(1)
n <- 50
samples <- rnorm(n)
library(margLikArrogance)
my.bw <- margLikArrogance:::.GetWidth(matrix(samples, ncol=1),
                                      matrix(rnorm(50), ncol=1),
                                      dnorm(samples, log=TRUE))
my.hist <- margLikArrogance:::.PopulateHist(matrix(samples, ncol=1),
                                            dnorm(samples, log=TRUE),
                                            my.bw)
my.hist <- margLikArrogance:::.SetHistNorm(my.hist)
my.xvals <- my.hist$center + my.bw * -n:n
my.xvals <- my.xvals[-3 < my.xvals & my.xvals < 3]
my.xvals <- c(rbind(my.xvals - .0001, my.xvals + .0001))
my.yvals <- (exp(sapply(my.xvals,
                        function(x) margLikArrogance:::.Lookup(
                                    matrix(x, ncol=1), my.hist))
                 - my.hist$norm))

trad.bw <- 3.5 * n^(-1/3)
trad.center <- -trad.bw / 2
trad.xvals <- trad.center + trad.bw * -100:100
trad.xvals <- trad.xvals[-3 < trad.xvals & trad.xvals < 3]
trad.xvals <- c(rbind(trad.xvals - .0001, trad.xvals + .0001))

TradHistLookup <- function(point, center=trad.center, bw=trad.bw) {
  # Return the height of the histogram at the given point
  lower <- floor((point - center) / bw) * bw + center
  upper <- lower + bw
  count <- length(samples[lower <= samples & samples < upper])
  return(count / n / bw)
}
trad.yvals <- sapply(trad.xvals, TradHistLookup)

trad.small.yvals <- sapply(my.xvals,
                           function(x) TradHistLookup(x, center=my.hist$center,
                                                      bw=my.hist$width))

xvals <- seq(from=-3, to=3, by=.1)
plot.df <- rbind(data.frame(x=xvals, y=dnorm(xvals), type="Density"),
                 data.frame(x=my.xvals, y=my.yvals, type="Arrogant Histogram"),
                 data.frame(x=my.xvals, y=trad.small.yvals,
                            type="Traditional Histogram"),
                 data.frame(x=trad.xvals, y=trad.yvals,
                            type="Trad Hist (Optimum BW)"))

hist.plot <- (ggplot(data=plot.df)
              + geom_area(aes(x=x, y=y), color=favir.colors["M5"],
                          fill=favir.colors["M5"])
              + facet_grid(type ~ ., scale="free")
#              + geom_vline(aes(xintercept=samples),
#                           data=data.frame(samples=samples, type="Density"),
#                           color=favir.colors["A5"], size=.15)
              + geom_rug(aes(x=samples), color=favir.colors["A5"], alpha=.5,
                         size=.5, data=data.frame(samples=samples))
              + labs(x="x", y="Probability Density"))
IncludeGraph(hist.plot, caption="Histogram Comparison", label="histograms",
             width=15.5, height=18)


